// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.0
import com.nokia.meego 1.0

Rectangle {
    id: rectangle1
    width: 480
    height: 854
    color:"#333333"
    property string photourl:"icons/contacts.svg"
    property string name:"Me"

    function setUrl(itsurl){
        photourl = itsurl;
    }

    function getDetails() {
        var db = openDatabaseSync("GlanceDB", "1.0", "Glance!", 1000000);

        db.transaction(
        function(tx) {
        tx.executeSql('CREATE TABLE IF NOT EXISTS Details(name TEXT, photo TEXT)');
        var rs = tx.executeSql('SELECT * FROM Details');
        var itsname = ""
        var itsphoto = ""
        for(var i = 0; i < rs.rows.length; i++) {
        itsname = rs.rows.item(i).name;
        itsphoto = rs.rows.item(i).photo;
        }
        photourl = itsphoto;
        name = itsname;
        }
        )
    }

    function saveDetails(itsname,itsurl) {
    var db = openDatabaseSync("GlanceDB", "1.0", "Glance!", 1000000);

    db.transaction(
    function(tx) {

    tx.executeSql('CREATE TABLE IF NOT EXISTS Details(name TEXT, photo TEXT)');
    tx.executeSql('DELETE From Details');
    tx.executeSql('INSERT INTO Details VALUES(?,?)', [itsname, itsurl]);

    }
    )
    }


    StatusBar {
        id: statusbar1
        height: 40
        anchors.top: parent.top
        anchors.topMargin: 0
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 0
    }

    Rectangle {
        id: rectangle2
        width: 200
        height: 200
        color: "#333333"
        border.width: 1
        border.color: "#111111"
        anchors.top: statusbar1.bottom
        anchors.topMargin: 0

        Image {
            id: image1
            fillMode: Image.PreserveAspectFit
            anchors.fill: parent
            source: photourl
        }
        MouseArea{
            z: 2
            anchors.fill:parent
            onClicked: {
            pageStack.push(glist);
        }
        }
    }

    Rectangle {
        id: rectangle3
        height: 60
        color: "#333333"
        anchors.top: rectangle2.bottom
        anchors.topMargin: 20
        anchors.left: parent.left
        anchors.leftMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 5

        Text {
            id: text1
            width: 60
            color: "#ffffff"
            text: qsTr("Name")
            font.pixelSize: 18
            font.bold: true
            font.family: "Arial Black"
            anchors.left: parent.left
            anchors.leftMargin: 5
            anchors.verticalCenter: parent.verticalCenter

        }

        TextField {
            id: txtname
            text: name
            anchors.right: parent.right
            anchors.rightMargin: 5
            anchors.left: text1.right
            anchors.leftMargin: 5
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 2
            anchors.top: parent.top
            anchors.topMargin: 2
    }
    }

    Button {
        id: save
        width: parent.width/2
        height: 50
        text: "Save"
        iconSource: ""
        anchors.top: rectangle3.bottom
        anchors.topMargin: 30
        anchors.horizontalCenter: parent.horizontalCenter
        onClicked: {
            saveDetails(txtname.text,photourl);
            pageStack.push(mappage);
        }
    }

    Rectangle {
       id: toolbar
       anchors.right: parent.right
       anchors.rightMargin: 2
       anchors.left: parent.left
       anchors.leftMargin: 2
       anchors.bottom: parent.bottom
       anchors.bottomMargin: 0
       opacity: 1
       height:60
       color: "#000000"
       border.color: "#ffffff"
       z: 1

       Rectangle {
           id: back
           width:parent.height
           color: "#000000"
           anchors.left: parent.left
           anchors.leftMargin: 2
           anchors.bottom: parent.bottom
           anchors.bottomMargin: 3
           anchors.top: parent.top
           anchors.topMargin: 3

           Image {
               id: backicon
               anchors.fill: parent
               fillMode: Image.PreserveAspectFit
               source: "icons/back.svg"
           }

           MouseArea {
               id: back_mouse_area
               anchors.leftMargin: 0
               anchors.fill: parent
               onClicked: {
                   pageStack.pop();
               }
       }
       }

       Rectangle {
           id: homerect
           width: 50
           color: "#000000"
           anchors.bottom: parent.bottom
           anchors.bottomMargin: 2
           anchors.top: parent.top
           anchors.topMargin: 2
           anchors.right: parent.right
           anchors.rightMargin: 2

           Image {
               id: homeicon
               fillMode: Image.PreserveAspectFit
               anchors.fill: parent
               source: "icons/home.svg"
           }

           MouseArea {
               id: home_mouse_area
               anchors.fill: parent
               onClicked: {
               pageStack.push(mappage);
               }

           }

       }


   }


    Dialog {
         id: savedialog
         anchors.horizontalCenter: parent.horizontalCenter
         anchors.verticalCenter: parent.verticalCenter
         content: Rectangle {
             id: rectangle4
             width: 300
             height: 300
             border.width: 2
             border.color: "#cccccc"
             anchors.horizontalCenter: parent.horizontalCenter
             color: "#000000"
             Text{
                 text:"Record Saved"
                 anchors.horizontalCenter: parent.horizontalCenter
                 anchors.verticalCenter: parent.verticalCenter
                 color:"#ffffff"
                 font.family: "Tahoma"
                 font.pixelSize: 18
                 height:40
             }

             Rectangle {
                 id:dlgbutton
                 state:"normal"
                 color:"#cccccc"
                 anchors.bottom:parent.bottom
                 anchors.bottomMargin: 5
                 anchors.left: parent.left
                 anchors.leftMargin: 10
                 anchors.right:parent.right
                 anchors.rightMargin: 10
                 radius:5
                 height:60
                 Text {
                     id: text2
                     text: qsTr("OK")
                     anchors.horizontalCenter: parent.horizontalCenter
                     anchors.verticalCenter: parent.verticalCenter
                     font.pixelSize: 14
                     font.family: "Arial Black"
                 }
                 MouseArea{
                 id: mousearea1
                 anchors.fill: parent
                 onClicked: {
                 savedialog.close();
                 }


                 }

                 states: [
                 State {
                 name: "clicked"
                 PropertyChanges { target: dlgbutton; color:"#ff9900" }
                 },
                 State {
                 name: "normal"
                 PropertyChanges { target: dlgbutton; color:"#cccccc" }
                 }
                 ]
             }


         }



     }
}
