import QtQuick 1.0
import com.nokia.meego 1.0
import QtMobility.location 1.1



Item {
     width: 480
     height: 480

     focus : true


     Map {
         id: map
         z : 1
         plugin : Plugin {
                             name : "nokia"
                         }
         size.width: parent.width
         size.height: parent.height
         zoomLevel: 14
         center: Coordinate {
             latitude: -1.297196
             longitude: 36.797595
         }

         MapCircle {
             id : circle
             center : Coordinate {
                         latitude : -1.297196
                         longitude : 36.797595
                     }
             color : "#80FF0000"
             radius : 1.0
             MapMouseArea {
                 onPositionChanged: {
                     if (mouse.button == Qt.LeftButton)
                         circle.center = mouse.coordinate
                     if (mouse.button == Qt.RightButton)
                         circle.radius = circle.center.distanceTo(mouse.coordinate)
                 }
             }
         }

         MapMouseArea {
             property int lastX : -1
             property int lastY : -1

             onPressed : {
                 lastX = mouse.x
                 lastY = mouse.y
             }
             onReleased : {
                 lastX = -1
                 lastY = -1
             }
             onPositionChanged: {
                 if (mouse.button == Qt.LeftButton) {
                     if ((lastX != -1) && (lastY != -1)) {
                         var dx = mouse.x - lastX
                         var dy = mouse.y - lastY
                         map.pan(-dx, -dy)
                     }
                     lastX = mouse.x
                     lastY = mouse.y
                 }
             }
             onDoubleClicked: {
                 map.center = mouse.coordinate
                 map.zoomLevel += 1
                 lastX = -1
                 lastY = -1
             }
         }
     }

     Keys.onPressed: {
         if (event.key == Qt.Key_Plus) {
             map.zoomLevel += 1
         } else if (event.key == Qt.Key_Minus) {
             map.zoomLevel -= 1
         } else if (event.key == Qt.Key_T) {
             if (map.mapType == Map.StreetMap) {
                 map.mapType = Map.SatelliteMapDay
             } else if (map.mapType == Map.SatelliteMapDay) {
                 map.mapType = Map.StreetMap
             }
         }
     }
 }
